Index: bfd/cpu-metag.c |
diff --git a/bfd/cpu-xtensa.c b/bfd/cpu-metag.c |
similarity index 75% |
copy from bfd/cpu-xtensa.c |
copy to bfd/cpu-metag.c |
index 5c1008e9ad4c345d041b3dda6ebfc703fe1c4e8b..a8dbfaa9bfdef3da8ddfa08979a202364278374e 100644 |
--- a/bfd/cpu-xtensa.c |
+++ b/bfd/cpu-metag.c |
@@ -1,5 +1,6 @@ |
-/* BFD support for the Xtensa processor. |
- Copyright 2003, 2005, 2007 Free Software Foundation, Inc. |
+/* BFD support for the Imagination Technologies Meta processor. |
+ Copyright (C) 2013 Free Software Foundation, Inc. |
+ Contributed by Imagination Technologies Ltd. |
This file is part of BFD, the Binary File Descriptor library. |
@@ -22,17 +23,17 @@ |
#include "bfd.h" |
#include "libbfd.h" |
-const bfd_arch_info_type bfd_xtensa_arch = |
+const bfd_arch_info_type bfd_metag_arch = |
{ |
32, /* Bits per word. */ |
32, /* Bits per address. */ |
8, /* Bits per byte. */ |
- bfd_arch_xtensa, /* Architecture. */ |
- bfd_mach_xtensa, /* Machine. */ |
- "xtensa", /* Architecture name. */ |
- "xtensa", /* Printable name. */ |
+ bfd_arch_metag, /* Architecture. */ |
+ bfd_mach_metag, /* Machine. */ |
+ "metag", /* Architecture name. */ |
+ "metag", /* Printable name. */ |
4, /* Section align power. */ |
- TRUE, /* The default? */ |
+ TRUE, /* The default ? */ |
bfd_default_compatible, /* Architecture comparison fn. */ |
bfd_default_scan, /* String to architecture convert fn. */ |
bfd_arch_default_fill, /* Default fill. */ |